@@ -5,7 +5,7 @@
 # --- BEGIN_HEADER ---
 #
 # __init__ - global signal convolution module init
-# Copyright (C) 2011-2012  The CPHHPC Project lead by Brian Vinter
+# Copyright (C) 2011-2014  The CPHHPC Project lead by Brian Vinter
 #
 # This file is part of CPHHPC Toolbox.
 #
@@ -35,4 +35,4 @@ from incorrectly moving following comments above module doc string'''
 
 # All sub modules to load in case of 'from X import *'
 
-__all__ = []
+__all__ = ['convolve2d']
